
Security Master
---------------

.. autosummary::
    :toctree: api/
    :template: ../../../../_templates/class_template.rst

    prismstudio.securitymaster.attribute
    prismstudio.securitymaster.list_attribute

